orion.primitives.azure\_anomaly\_detector.split\_sequence
=========================================================

.. currentmodule:: orion.primitives.azure_anomaly_detector

.. autofunction:: split_sequence